==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/ButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ButtonClickEventArgsDescription } from "./ButtonClickEventArgsDescription";
/**
 * @hidden
 */
var ButtonClickEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ButtonClickEventArgsDescriptionMetadata, _super);
    function ButtonClickEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ButtonClickEventArgsDescriptionMetadata.b = function (a) {
        if (ButtonClickEventArgsDescriptionMetadata.a == null) {
            ButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ButtonClickEventArgsDescriptionMetadata.c(ButtonClickEventArgsDescriptionMetadata.a);
        }
        if (a.g(ButtonClickEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(ButtonClickEventArgsDescriptionMetadata.a);
    };
    ButtonClickEventArgsDescriptionMetadata.c = function (a) {
    };
    ButtonClickEventArgsDescriptionMetadata.d = function (a) {
        ButtonClickEventArgsDescriptionMetadata.b(a);
        a.u("ButtonClickEventArgs", function () { return new ButtonClickEventArgsDescription(); });
        a.t("ButtonClickEventArgs", ButtonClickEventArgsDescriptionMetadata.a);
    };
    ButtonClickEventArgsDescriptionMetadata.$t = markType(ButtonClickEventArgsDescriptionMetadata, 'ButtonClickEventArgsDescriptionMetadata');
    ButtonClickEventArgsDescriptionMetadata.a = null;
    return ButtonClickEventArgsDescriptionMetadata;
}(Base));
export { ButtonClickEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/ButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ButtonClickEventArgsDescription } from "./ButtonClickEventArgsDescription";
/**
 * @hidden
 */
var ButtonClickEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ButtonClickEventArgsDescriptionMetadata, _super);
    function ButtonClickEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ButtonClickEventArgsDescriptionMetadata.b = function (a) {
        if (ButtonClickEventArgsDescriptionMetadata.a == null) {
            ButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ButtonClickEventArgsDescriptionMetadata.c(ButtonClickEventArgsDescriptionMetadata.a);
        }
        if (a.j(ButtonClickEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ButtonClickEventArgsDescriptionMetadata.a);
    };
    ButtonClickEventArgsDescriptionMetadata.c = function (a) {
    };
    ButtonClickEventArgsDescriptionMetadata.d = function (a) {
        ButtonClickEventArgsDescriptionMetadata.b(a);
        a.aa("ButtonClickEventArgs", function () { return new ButtonClickEventArgsDescription(); });
        a.z("ButtonClickEventArgs", ButtonClickEventArgsDescriptionMetadata.a);
    };
    ButtonClickEventArgsDescriptionMetadata.$t = markType(ButtonClickEventArgsDescriptionMetadata, 'ButtonClickEventArgsDescriptionMetadata');
    ButtonClickEventArgsDescriptionMetadata.a = null;
    return ButtonClickEventArgsDescriptionMetadata;
}(Base));
export { ButtonClickEventArgsDescriptionMetadata };
